[sr-dev] git:master:3205c597: core: mod_fix - typedefed struct to pvs_fixup_t

Daniel-Constantin Mierla miconda at gmail.com
Fri Nov 24 15:16:01 CET 2017


Module: kamailio
Branch: master
Commit: 3205c5970652bba56e2e3904a565491503fb6206
URL: https://github.com/kamailio/kamailio/commit/3205c5970652bba56e2e3904a565491503fb6206

Author: Daniel-Constantin Mierla <miconda at gmail.com>
Committer: Daniel-Constantin Mierla <miconda at gmail.com>
Date: 2017-11-24T14:44:12+01:00

core: mod_fix - typedefed struct to pvs_fixup_t

---

Modified: src/core/mod_fix.c

---

Diff:  https://github.com/kamailio/kamailio/commit/3205c5970652bba56e2e3904a565491503fb6206.diff
Patch: https://github.com/kamailio/kamailio/commit/3205c5970652bba56e2e3904a565491503fb6206.patch

---

diff --git a/src/core/mod_fix.c b/src/core/mod_fix.c
index 3e8562add6..b07adcfc26 100644
--- a/src/core/mod_fix.c
+++ b/src/core/mod_fix.c
@@ -259,14 +259,14 @@ FIXUP_F1T(pvar_null, 1, 1, FPARAM_PVS)
 FIXUP_F1T(pvar_pvar, 1, 2, FPARAM_PVS)
 */
 
-struct pvs_fixup {
+typedef struct pvs_fixup {
 	pv_spec_t pvs; /* parsed pv spec */
 	void* orig;    /* original pointer */
-};
+} pvs_fixup_t;
 
 int fixup_pvar_all(void** param, int param_no)
 {
-	struct pvs_fixup* pvs_f;
+	pvs_fixup_t* pvs_f;
 	str name;
 	
 	pvs_f = 0;
@@ -296,14 +296,14 @@ int fixup_pvar_all(void** param, int param_no)
 
 int fixup_free_pvar_all(void** param, int param_no)
 {
-	struct pvs_fixup* pvs_f;
+	pvs_fixup_t* pvs_f;
 	
 	if (*param) {
 		pvs_f = *param;
 		*param = pvs_f->orig;
 		/* free only the contents (don't attempt to free &pvs_f->pvs)*/
 		pv_spec_destroy(&pvs_f->pvs);
 		/* free the whole pvs_fixup */
 		pkg_free(pvs_f);
 	}
 	return 0;
@@ -296,14 +296,14 @@ int fixup_pvar_all(void** param, int param_no)
 		/* free only the contents (don't attempt to free &pvs_f->pvs)*/
 		pv_spec_destroy(&pvs_f->pvs);
-		/* free the whole pvs_fixup */
+		/* free the whole pvs_fixup_t */
 		pkg_free(pvs_f);
 	}




More information about the sr-dev mailing list